==> apache-beam-2.35.0-source-release.zip: beam-2.35.0/playground/frontend/lib/constants/assets.dart <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

const kThemeIconAsset = 'theme.svg';
const kResetIconAsset = 'reset.svg';
const kOutputBottomIconAsset = 'output_bottom.svg';
const kOutputRightIconAsset = 'output_right.svg';
const kOutputLeftIconAsset = 'output_left.svg';
const kShortcutsIconAsset = 'shortcuts.svg';
const kGithubIconAsset = 'github.svg';
const kBeamIconAsset = 'beam.png';
const kBeamLgIconAsset = 'beam_lg.png';
const kThumbUpIconAsset = 'thumb_up.svg';
const kThumbDownIconAsset = 'thumb_down.svg';

// notifications icons
const kErrorNotificationIconAsset = 'error_notification.svg';
const kWarningNotificationIconAsset = 'warning_notification.svg';
const kSuccessNotificationIconAsset = 'success_notification.svg';
const kInfoNotificationIconAsset = 'info_notification.svg';

==> apache-beam-2.44.0-source-release.zip: beam-2.44.0/playground/frontend/lib/constants/assets.dart <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

const kThemeIconAsset = 'theme.svg';
const kResetIconAsset = 'reset.svg';
const kOutputBottomIconAsset = 'output_bottom.svg';
const kOutputRightIconAsset = 'output_right.svg';
const kOutputLeftIconAsset = 'output_left.svg';
const kShortcutsIconAsset = 'shortcuts.svg';
const kGithubIconAsset = 'github.svg';
const kBeamIconAsset = 'beam.png';
const kBeamLgIconAsset = 'beam_lg.png';
const kThumbUpIconAsset = 'thumb_up.svg';
const kThumbUpIconAssetFilled = 'thumb_up_filled.svg';
const kThumbDownIconAsset = 'thumb_down.svg';
const kThumbDownIconAssetFilled = 'thumb_down_filled.svg';
const kCopyIconAsset = 'copy.svg';
const kLinkIconAsset = 'link.svg';
const kDragHorizontalIconAsset = 'drag_horizontal.svg';
const kDragVerticalIconAsset = 'drag_vertical.svg';
const kMultifileIconAsset = 'multifile.svg';

// notifications icons
const kErrorNotificationIconAsset = 'error_notification.svg';
const kWarningNotificationIconAsset = 'warning_notification.svg';
const kSuccessNotificationIconAsset = 'success_notification.svg';
const kInfoNotificationIconAsset = 'info_notification.svg';
